summaryrefslogtreecommitdiffstats
path: root/crypto/engine/eng_int.h
diff options
context:
space:
mode:
authorGeoff Thorpe <geoff@openssl.org>2001-09-25 21:28:40 +0000
committerGeoff Thorpe <geoff@openssl.org>2001-09-25 21:28:40 +0000
commitb370230b786eed9b73c9a1f5c0a5e008e8009989 (patch)
tree48fc5a3a1fadc9a274582cea6a46823438f151f4 /crypto/engine/eng_int.h
parent50a381b789f9e850632847d30ea81fb762e6b989 (diff)
This change adds cipher and digest support into ENGINE using the
ENGING_TABLE mechanism. The necessary hooks from crypto/evp/ to use this will be committed shortly.
Diffstat (limited to 'crypto/engine/eng_int.h')
-rw-r--r--crypto/engine/eng_int.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/crypto/engine/eng_int.h b/crypto/engine/eng_int.h
index e07da813b6..65ba9d43a6 100644
--- a/crypto/engine/eng_int.h
+++ b/crypto/engine/eng_int.h
@@ -138,6 +138,11 @@ struct engine_st
const DSA_METHOD *dsa_meth;
const DH_METHOD *dh_meth;
const RAND_METHOD *rand_meth;
+ /* Cipher handling is via this callback */
+ ENGINE_CIPHERS_PTR ciphers;
+ /* Digest handling is via this callback */
+ ENGINE_DIGESTS_PTR digests;
+
ENGINE_GEN_INT_FUNC_PTR destroy;
@@ -157,7 +162,7 @@ struct engine_st
* simply to cope with (de)allocation of this structure. Hence,
* running_ref <= struct_ref at all times. */
int funct_ref;
/* A place to store per-key data */
CRYPTO_EX_DATA ex_data;
/* Used to maintain the linked-list of engines. */
struct engine_st *prev;
@@ -157,7 +162,7 @@ struct engine_st
* running_ref <= struct_ref at all times. */
int funct_ref;
- /* A place to store per-key data */
+ /* A place to store per-ENGINE data */
CRYPTO_EX_DATA ex_data;
/* Used to maintain the linked-list of engines. */